- lmmodel
The model of interest, output of either
lmer or glmer, that is, an
object of class merMod and
subclass either lmerMod or glmerMod.
- boundary_check
A length 1 boolean object (TRUE [default]
or FALSE), determining if the function removes those random
effects which make the model singular (in the simplest situation,
those with standard deviation almost 0.
- scale
A length 1 boolean object (TRUE or FALSE
[default]), determining if the function must rescale the numeric
predictors when this action is asked in a warning or
message.
- scale_info
A length 1 boolean object (TRUE [default] or
FALSE), determining if the function should cat a message when
some predictor variables are on very different scales, but are not
rescaled.
- tol
A numeric value (default is 1e-4), tolerance under
which to consider if a model is singular (see boundary_check
argument).
- max_message_iter
A numeric value (default is 7),
generally the maximum number of iterations allowed to update the
model. For the exception, see the Details section.
- pri_nAGQ
A length 1 boolean object (TRUE or FALSE
[default]), determining if the function prioritizes incrising
nAGQ over updating model start parameters when both are
possible solutions to warned issues.
- max_nAGQ
A numeric value (default is 6), maximum to
which increase the nAGQ argument fitting
glmer models.
- next_optimizer
An optimizer (default is "bobyqa"), next
to be used when model convergence is failing.
- next_optCtrl
A list (default is
list(maxfun=2e5)) of additional arguments to be passed to the
nonlinear optimizer (see Nelder_Mead,
bobyqa). In particular, both Nelder_Mead
and bobyqa use maxfun to specify the maximum number of
function evaluations they will try before giving up - in contrast to
optim and optimx-wrapped optimizers, which use
maxit. (Also see convergence for details
of stopping tolerances for different optimizers.
- when_next
A numeric value not greater than
max_message_iter - 1 (which is the default), specifying from
which iteration a model convergence failing is approached with a new
optimizer (next_optimizer) and with a new set of arguments to
it (next_optCtrl).
- verbose
A length 1 boolean object (TRUE or FALSE
[default])
specifying if function iterations and model updating
should be verbose.