issue618: Data example github issue 618 on the lme4 repository
Description
Three variables, being one dichotomous, other continuous and the last,
categorical. Data for the first reproducible example for issue 618 on
the lme4 Github-repository, making glmer to produce a
Model is nearly unidentifiable: very large eigenvalue -
Rescale variables?
warning for the model outcome_dead ~ AGE +
(1|ZIP).
Usage
data("issue618")
Arguments
Format
A data frame with 1000 observations on the following 3 variables.