Learn R Programming

trouBBlme4SolveR (version 0.1.4)

issue618large: Data example github issue 618 on the lme4 repository

Description

Three variables, being one dichotomous, other continuous and the last, categorical. Data for the first reproducible example for issue 618 on the lme4 Github-repository, making glmer to produce a

Model is nearly unidentifiable: very large eigenvalue -
		Rescale variables?

warning for the model outcome_dead ~ AGE + (1|ZIP).

Usage

data("issue618")

Arguments

Format

A data frame with 1000 observations on the following 3 variables.

outcome_dead

an integer vector

AGE

an integer vector

ZIP

an integer vector

Examples

Run this code
data(issue618large)
str(issue618large)
# \donttest{
library(lme4)
m1<- glmer(outcome_dead ~ AGE + (1|ZIP), family = binomial, data = issue618large)
summary(m1)
m2 <- dwmw(m1, scale = TRUE)
summary(m2)
m3 <- glmer(outcome_dead ~ scale(AGE) + (1|ZIP), family = binomial, data = issue618large, 
	    nAGQ=20)
aa <- allFit(m3)
ss <- summary(aa)
ss$msgs  ## all NULL
# }

Run the code above in your browser using DataLab